@@ -70,7 +70,7 @@ class Exceptions:
 
 class FinSpaceDataClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html)
     """
 
@@ -86,7 +86,7 @@ class FinSpaceDataClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#can_paginate)
         """
 
@@ -102,7 +102,7 @@ class FinSpaceDataClient(BaseClient):
         """
         Creates a new Changeset in a FinSpace Dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Client.create_changeset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Client.create_changeset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#create_changeset)
         """
 
@@ -120,7 +120,7 @@ class FinSpaceDataClient(BaseClient):
         """
         Creates a Dataview for a Dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Client.create_data_view)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Client.create_data_view)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#create_data_view)
         """
 
@@ -129,17 +129,17 @@ class FinSpaceDataClient(BaseClient):
         *,
         datasetTitle: str,
         kind: DatasetKindType,
-        datasetDescription: str,
         permissionGroupParams: "PermissionGroupParamsTypeDef",
-        alias: str,
         clientToken: str = ...,
+        datasetDescription: str = ...,
         ownerInfo: "DatasetOwnerInfoTypeDef" = ...,
+        alias: str = ...,
         schemaDefinition: "SchemaUnionTypeDef" = ...
     ) -> CreateDatasetResponseTypeDef:
         """
         Creates a new FinSpace Dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Client.create_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Client.create_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#create_dataset)
         """
 
@@ -149,7 +149,7 @@ class FinSpaceDataClient(BaseClient):
         """
         Deletes a FinSpace Dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Client.delete_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Client.delete_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#delete_dataset)
         """
 
@@ -163,7 +163,7 @@ class FinSpaceDataClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#generate_presigned_url)
         """
 
@@ -171,7 +171,7 @@ class FinSpaceDataClient(BaseClient):
         """
         Get information about a Changeset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Client.get_changeset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Client.get_changeset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_changeset)
         """
 
@@ -179,7 +179,7 @@ class FinSpaceDataClient(BaseClient):
         """
         Gets information about a Dataview.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Client.get_data_view)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Client.get_data_view)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_data_view)
         """
 
@@ -187,7 +187,7 @@ class FinSpaceDataClient(BaseClient):
         """
         Returns information about a Dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Client.get_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Client.get_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_dataset)
         """
 
@@ -197,7 +197,7 @@ class FinSpaceDataClient(BaseClient):
         """
         Request programmatic credentials to use with FinSpace SDK.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Client.get_programmatic_access_credentials)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Client.get_programmatic_access_credentials)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_programmatic_access_credentials)
         """
 
@@ -208,7 +208,7 @@ class FinSpaceDataClient(BaseClient):
         A temporary Amazon S3 location, where you can copy your files from a source
         location to stage or use as a scratch space in FinSpace notebook.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Client.get_working_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Client.get_working_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_working_location)
         """
 
@@ -218,7 +218,7 @@ class FinSpaceDataClient(BaseClient):
         """
         Lists the FinSpace Changesets for a Dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Client.list_changesets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Client.list_changesets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#list_changesets)
         """
 
@@ -228,7 +228,7 @@ class FinSpaceDataClient(BaseClient):
         """
         Lists all available Dataviews for a Dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Client.list_data_views)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Client.list_data_views)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#list_data_views)
         """
 
@@ -238,7 +238,7 @@ class FinSpaceDataClient(BaseClient):
         """
         Lists all of the active Datasets that a user has access to.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Client.list_datasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Client.list_datasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#list_datasets)
         """
 
@@ -254,7 +254,7 @@ class FinSpaceDataClient(BaseClient):
         """
         Updates a FinSpace Changeset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Client.update_changeset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Client.update_changeset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#update_changeset)
         """
 
@@ -264,35 +264,35 @@ class FinSpaceDataClient(BaseClient):
         datasetId: str,
         datasetTitle: str,
         kind: DatasetKindType,
-        alias: str,
         clientToken: str = ...,
         datasetDescription: str = ...,
+        alias: str = ...,
         schemaDefinition: "SchemaUnionTypeDef" = ...
     ) -> UpdateDatasetResponseTypeDef:
         """
         Updates a FinSpace Dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Client.update_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Client.update_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#update_dataset)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_changesets"]) -> ListChangesetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Paginator.ListChangesets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Paginator.ListChangesets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/paginators.html#listchangesetspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_data_views"]) -> ListDataViewsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Paginator.ListDataViews)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Paginator.ListDataViews)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/paginators.html#listdataviewspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_datasets"]) -> ListDatasetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.11/reference/services/finspace-data.html#FinSpaceData.Paginator.ListDatasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/finspace-data.html#FinSpaceData.Paginator.ListDatasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/paginators.html#listdatasetspaginator)
         """
