@@ -26,6 +26,7 @@ __all__ = (
     "DatasetKindType",
     "DatasetStatusType",
     "ErrorCategoryType",
+    "ExportFileFormatType",
     "IngestionStatusType",
     "ListChangesetsPaginatorName",
     "ListDataViewsPaginatorName",
@@ -73,6 +74,7 @@ ErrorCategoryType = Literal[
     "USER_RECOVERABLE",
     "VALIDATION",
 ]
+ExportFileFormatType = Literal["DELIMITED_TEXT", "PARQUET"]
 IngestionStatusType = Literal["FAILED", "PENDING", "RUNNING", "STOP_REQUESTED", "SUCCESS"]
 ListChangesetsPaginatorName = Literal["list_changesets"]
 ListDataViewsPaginatorName = Literal["list_data_views"]
@@ -87,6 +89,7 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
@@ -106,6 +109,7 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
     "braket",
     "budgets",
@@ -182,6 +186,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -208,6 +213,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -221,6 +227,7 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
     "kafka",
@@ -266,6 +273,7 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
     "migrationhubstrategy",
     "mobile",
@@ -296,6 +304,7 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
@@ -311,6 +320,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -368,6 +378,7 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
 PaginatorName = Literal["list_changesets", "list_data_views", "list_datasets"]
